.. py:function:: sf_bessel_Kn(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Kn`
    c code signature: double gsl_sf_bessel_Kn(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_i0_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_i0_scaled_e`
    c code signature: int gsl_sf_bessel_i0_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_i1_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_i1_scaled`
    c code signature: double gsl_sf_bessel_i1_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_K1_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_K1_scaled`
    c code signature: double gsl_sf_bessel_K1_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_K0(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_K0`
    c code signature: double gsl_sf_bessel_K0(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_i0_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_i0_scaled`
    c code signature: double gsl_sf_bessel_i0_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_k0_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_k0_scaled`
    c code signature: double gsl_sf_bessel_k0_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_J0_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_J0_e`
    c code signature: int gsl_sf_bessel_J0_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_Y0_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Y0_e`
    c code signature: int gsl_sf_bessel_Y0_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_Inu_scaled(nu, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Inu_scaled`
    c code signature: double gsl_sf_bessel_Inu_scaled( double nu,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_i2_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_i2_scaled`
    c code signature: double gsl_sf_bessel_i2_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_I1_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_I1_scaled_e`
    c code signature: int gsl_sf_bessel_I1_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_lnKnu_e(nu, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_lnKnu_e`
    c code signature: int gsl_sf_bessel_lnKnu_e(const double nu, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_j1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_j1_e`
    c code signature: int gsl_sf_bessel_j1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_Knu_scaled(nu, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Knu_scaled`
    c code signature: double gsl_sf_bessel_Knu_scaled(const double nu, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_i1_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_i1_scaled_e`
    c code signature: int gsl_sf_bessel_i1_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_j1(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_j1`
    c code signature: double gsl_sf_bessel_j1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Knu_e(nu, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Knu_e`
    c code signature: int gsl_sf_bessel_Knu_e(const double nu, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_I1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_I1_e`
    c code signature: int gsl_sf_bessel_I1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_il_scaled_e(l, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_il_scaled_e`
    c code signature: int gsl_sf_bessel_il_scaled_e(const int l,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_Inu_e(nu, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Inu_e`
    c code signature: int gsl_sf_bessel_Inu_e( double nu,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_Y1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Y1_e`
    c code signature: int gsl_sf_bessel_Y1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_lnKnu(nu, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_lnKnu`
    c code signature: double gsl_sf_bessel_lnKnu(const double nu, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Jnu(nu, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Jnu`
    c code signature: double gsl_sf_bessel_Jnu(const double nu, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_K1(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_K1`
    c code signature: double gsl_sf_bessel_K1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Kn_scaled(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Kn_scaled`
    c code signature: double gsl_sf_bessel_Kn_scaled(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_y0(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_y0`
    c code signature: double gsl_sf_bessel_y0(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_I1(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_I1`
    c code signature: double gsl_sf_bessel_I1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_zero_Jnu(nu, s [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_zero_Jnu`
    c code signature: double gsl_sf_bessel_zero_Jnu( double nu,  unsigned int s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_ui__Rd__O`
    
    :param double nu: positional argument 0
    :param unsigned int s: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_i2_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_i2_scaled_e`
    c code signature: int gsl_sf_bessel_i2_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_y1(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_y1`
    c code signature: double gsl_sf_bessel_y1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Jn_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Jn_e`
    c code signature: int gsl_sf_bessel_Jn_e( int n,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_Yn_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Yn_e`
    c code signature: int gsl_sf_bessel_Yn_e( int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_jl(l, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_jl`
    c code signature: double gsl_sf_bessel_jl(const int l, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_K1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_K1_e`
    c code signature: int gsl_sf_bessel_K1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_Inu(nu, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Inu`
    c code signature: double gsl_sf_bessel_Inu( double nu,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_zero_J1(s [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_zero_J1`
    c code signature: double gsl_sf_bessel_zero_J1( unsigned int s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rd__O`
    
    :param unsigned int s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Y1(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Y1`
    c code signature: double gsl_sf_bessel_Y1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_y1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_y1_e`
    c code signature: int gsl_sf_bessel_y1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_y2(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_y2`
    c code signature: double gsl_sf_bessel_y2(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Knu_scaled_e10_e(nu, x [, ret, result])

    Wrapper for :c:func:`gsl_sf_bessel_Knu_scaled_e10_e`
    c code signature: int gsl_sf_bessel_Knu_scaled_e10_e(const double nu, const double x, gsl_sf_result_e10* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Oerd`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param gsl_sf_result_e10 result: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 2, :param gsl_sf_result_e10 result: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_I0(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_I0`
    c code signature: double gsl_sf_bessel_I0(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_yl_e(l, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_yl_e`
    c code signature: int gsl_sf_bessel_yl_e( int l, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_j0_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_j0_e`
    c code signature: int gsl_sf_bessel_j0_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_zero_J0_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_zero_J0_e`
    c code signature: int gsl_sf_bessel_zero_J0_e( unsigned int s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rl__Ord`
    
    :param unsigned int s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_I1_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_I1_scaled`
    c code signature: double gsl_sf_bessel_I1_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Knu(nu, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Knu`
    c code signature: double gsl_sf_bessel_Knu(const double nu, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_k1_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_k1_scaled`
    c code signature: double gsl_sf_bessel_k1_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_J1(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_J1`
    c code signature: double gsl_sf_bessel_J1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_k2_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_k2_scaled_e`
    c code signature: int gsl_sf_bessel_k2_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_Jnu_e(nu, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Jnu_e`
    c code signature: int gsl_sf_bessel_Jnu_e(const double nu, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_y2_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_y2_e`
    c code signature: int gsl_sf_bessel_y2_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_k2_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_k2_scaled`
    c code signature: double gsl_sf_bessel_k2_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_kl_scaled(l, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_kl_scaled`
    c code signature: double gsl_sf_bessel_kl_scaled(const int l, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Kn_scaled_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Kn_scaled_e`
    c code signature: int gsl_sf_bessel_Kn_scaled_e( int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_zero_Jnu_e(nu, s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_zero_Jnu_e`
    c code signature: int gsl_sf_bessel_zero_Jnu_e( double nu,  unsigned int s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_ui__Rl__Ord`
    
    :param double nu: positional argument 0
    :param unsigned int s: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_In_scaled(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_In_scaled`
    c code signature: double gsl_sf_bessel_In_scaled(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_I0_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_I0_scaled_e`
    c code signature: int gsl_sf_bessel_I0_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_Y0(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Y0`
    c code signature: double gsl_sf_bessel_Y0(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_il_scaled(l, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_il_scaled`
    c code signature: double gsl_sf_bessel_il_scaled(const int l, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Ynu(nu, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Ynu`
    c code signature: double gsl_sf_bessel_Ynu(const double nu, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Inu_scaled_e(nu, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Inu_scaled_e`
    c code signature: int gsl_sf_bessel_Inu_scaled_e( double nu,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_Knu_scaled_e(nu, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Knu_scaled_e`
    c code signature: int gsl_sf_bessel_Knu_scaled_e(const double nu, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_Ynu_e(nu, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Ynu_e`
    c code signature: int gsl_sf_bessel_Ynu_e( double nu,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double nu: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_j2_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_j2_e`
    c code signature: int gsl_sf_bessel_j2_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_zero_J1_e(s [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_zero_J1_e`
    c code signature: int gsl_sf_bessel_zero_J1_e( unsigned int s, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rl__Ord`
    
    :param unsigned int s: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_Kn_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_Kn_e`
    c code signature: int gsl_sf_bessel_Kn_e(const int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_Jn(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Jn`
    c code signature: double gsl_sf_bessel_Jn(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_k0_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_k0_scaled_e`
    c code signature: int gsl_sf_bessel_k0_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_I0_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_I0_e`
    c code signature: int gsl_sf_bessel_I0_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_yl(l, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_yl`
    c code signature: double gsl_sf_bessel_yl(const int l, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_j0(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_j0`
    c code signature: double gsl_sf_bessel_j0(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_Yn(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_Yn`
    c code signature: double gsl_sf_bessel_Yn(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_j2(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_j2`
    c code signature: double gsl_sf_bessel_j2(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_y0_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_y0_e`
    c code signature: int gsl_sf_bessel_y0_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_In_scaled_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_In_scaled_e`
    c code signature: int gsl_sf_bessel_In_scaled_e( int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_K0_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_K0_scaled_e`
    c code signature: int gsl_sf_bessel_K0_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_In_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_In_e`
    c code signature: int gsl_sf_bessel_In_e(const int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_K1_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_K1_scaled_e`
    c code signature: int gsl_sf_bessel_K1_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_jl_e(l, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_jl_e`
    c code signature: int gsl_sf_bessel_jl_e(const int l, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_J1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_J1_e`
    c code signature: int gsl_sf_bessel_J1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_K0_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_K0_scaled`
    c code signature: double gsl_sf_bessel_K0_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_kl_scaled_e(l, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_kl_scaled_e`
    c code signature: int gsl_sf_bessel_kl_scaled_e( int l, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_bessel_K0_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_K0_e`
    c code signature: int gsl_sf_bessel_K0_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_J0(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_J0`
    c code signature: double gsl_sf_bessel_J0(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_k1_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_bessel_k1_scaled_e`
    c code signature: int gsl_sf_bessel_k1_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_bessel_I0_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_I0_scaled`
    c code signature: double gsl_sf_bessel_I0_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_In(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_In`
    c code signature: double gsl_sf_bessel_In(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_bessel_zero_J0(s [, ret])

    Wrapper for :c:func:`gsl_sf_bessel_zero_J0`
    c code signature: double gsl_sf_bessel_zero_J0( unsigned int s)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Iui__Rd__O`
    
    :param unsigned int s: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

